@@ -5,7 +5,7 @@
 # escalations.py
 # Classes dealing directly with OpsRamp Alert Escalation Policies.
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2020 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,16 +20,13 @@
 # limitations under the License.
 
 from __future__ import print_function
-from opsramp.base import ApiWrapper
+from opsramp.api import ORapi
 
 
-class Escalations(ApiWrapper):
+class Escalations(ORapi):
     def __init__(self, parent):
         super(Escalations, self).__init__(parent.api, 'escalations')
 
-    def search(self, pattern=''):
-        return self.api.get('/search?%s' % pattern)
-
     def create(self, definition):
         return self.api.post('', json=definition)
 
