@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2020 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -66,7 +66,7 @@ class TrackerTest(unittest.TestCase):
                 assert not pshort
                 self.trkr.popd()
             else:
-                assert False
+                raise AssertionError('unexpected action %s' % action)
             assert self.trkr.fullpath() == pfull
 
     def test_reset(self):
